@@ -352,8 +352,21 @@ brasero_video_options_set_session (BraseroVideoOptions *options,
 	if (session) {
 		priv->session = g_object_ref (session);
 		brasero_video_options_update (options);
-		brasero_video_options_update_from_tag (options, BRASERO_VIDEO_OUTPUT_FRAMERATE);
-		brasero_video_options_update_from_tag (options, BRASERO_VIDEO_OUTPUT_ASPECT);
+
+		if (brasero_burn_session_tag_lookup (session, BRASERO_VIDEO_OUTPUT_FRAMERATE, NULL) == BRASERO_BURN_OK)
+			brasero_video_options_update_from_tag (options, BRASERO_VIDEO_OUTPUT_FRAMERATE);
+
+		/* If session has tag update UI otherwise update _from_ UI */
+		if (brasero_burn_session_tag_lookup (session, BRASERO_VIDEO_OUTPUT_ASPECT, NULL) == BRASERO_BURN_OK)
+			brasero_video_options_update_from_tag (options, BRASERO_VIDEO_OUTPUT_ASPECT);
+		else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->button_4_3)))
+			brasero_burn_session_tag_add_int (priv->session,
+			                                  BRASERO_VIDEO_OUTPUT_ASPECT,
+	        			                  BRASERO_VIDEO_ASPECT_4_3);
+		else
+			brasero_burn_session_tag_add_int (priv->session,
+				                          BRASERO_VIDEO_OUTPUT_ASPECT,
+				                          BRASERO_VIDEO_ASPECT_16_9);
 
 		g_signal_connect (priv->session,
 		                  "output-changed",
@@ -372,12 +385,8 @@ brasero_video_options_set_property (GObject *object,
 				    const GValue *value,
 				    GParamSpec *pspec)
 {
-	BraseroVideoOptionsPrivate *priv;
-
 	g_return_if_fail (BRASERO_IS_VIDEO_OPTIONS (object));
 
-	priv = BRASERO_VIDEO_OPTIONS_PRIVATE (object);
-
 	switch (prop_id)
 	{
 	case PROP_SESSION:
@@ -503,8 +512,7 @@ brasero_video_options_init (BraseroVideoOptions *object)
 			  GTK_FILL,
 			  0, 0);
 
-	button1 = gtk_radio_button_new_with_mnemonic (NULL,
-						      _("_4:3"));
+	button1 = gtk_radio_button_new_with_mnemonic (NULL, _("_4:3"));
 	g_signal_connect (button1,
 			  "toggled",
 			  G_CALLBACK (brasero_video_options_4_3),
